#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_INCLUDED_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_INCLUDED_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/scalar/is_included.hpp>

#endif
